==> ejc-metadata-api-3.0.0-20231222.032938-295-sources.jar: com/ejianc/foundation/metadata/vo/MdAttributeVO.java <==
package com.ejianc.foundation.metadata.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

public class MdAttributeVO extends BaseVO {

	private static final long serialVersionUID = 1L;
	public static final String DATA_TYPE_STRING = "string";
	public static final String DATA_TYPE_INTEGER = "integer";
	public static final String DATA_TYPE_LONG = "long";
	public static final String DATA_TYPE_DATETIME = "datetime";
	public static final String DATA_TYPE_DATE = "date";
	public static final String DATA_TYPE_LIST = "list";
	public static final String DATA_TYPE_REFER = "refer";
	public static final String DATA_TYPE_BOOLEAN = "boolean";
	public static final String DATA_TYPE_DECIMAL = "decimal";
	public static final String DATA_TYPE_FLOAT = "float";
	public static final String DATA_TYPE_DOUBLE = "double";

	private String attributeName; // 属性名称

	private String displayName; // 显示名称

	private String dataType; // 数据类型

	private String customDataType; // custom数据类型

	private String description;// 描述

	private Integer dataLength;// 数据长度

	private Integer decimalPlace;// 小数位

	private String columnName; // 列名

	private boolean nullFlag; // 是否为空

	private boolean keyFlag; // 是否主键

	private Long entityId; // 实体ID

	private boolean sensitiveFlag;// 是否是敏感字段

	private Integer sequence;// 排序字段

	private boolean refFlag; // 是否参照字段

	private String refMapField;// 参照映射字段

	private Long parentId; // 其关系表 ， 获取属性参照使用
	private String code;// 流程中心使用
	private String name;// 流程中心使用
	private String mainAttributeField;// 当该实体为子实体时，该字段表示该子实体在主实体中的属性

	private boolean foreignKeyFlag; //是否外键，若是，则该字段为主表主键

	private String dataFormat; //数据格式化，打印使用
	
	private String sourceType; //当该字段为图片时对应的sourceType（附件上传时定义的sourceType），打印图片使用
	
	private String referCode; //参照编码（当字段为参照字段时，填写参照编码）

	/**
	 * 查询时字段排序方式（目前用于打印查询），""-不排序，"desc"-倒序,"asc"-正序
	 */
	private String orderType;

	/**
	 * 查询时字段排序顺序
	 */
	private Integer orderSequence;
	
	private boolean editFlag;// 是否允许审批中可改

	private String mainAttributeName;// 子表名字 业财中台使用
	private String columnPos; // 字段位置:H主表、HR主表关联、B子表、BR子表关联  业财中台使用

	public String getMainAttributeName() {
		return mainAttributeName;
	}

	public void setMainAttributeName(String mainAttributeName) {
		this.mainAttributeName = mainAttributeName;
	}

	public String getColumnPos() {
		return columnPos;
	}

	public void setColumnPos(String columnPos) {
		this.columnPos = columnPos;
	}

	public String getOrderType() {
		return orderType;
	}

	public void setOrderType(String orderType) {
		this.orderType = orderType;
	}

	public Integer getOrderSequence() {
		return orderSequence;
	}

	public void setOrderSequence(Integer orderSequence) {
		this.orderSequence = orderSequence;
	}

	public String getAttributeName() {
		return attributeName;
	}

	public void setAttributeName(String attributeName) {
		this.attributeName = attributeName;
	}

	public String getDisplayName() {
		return displayName;
	}

	public void setDisplayName(String displayName) {
		this.displayName = displayName;
	}

	public String getDataType() {
		return dataType;
	}

	public void setDataType(String dataType) {
		this.dataType = dataType;
	}

	public String getDescription() {
		return description;
	}

	public void setDescription(String description) {
		this.description = description;
	}

	public Integer getDataLength() {
		return dataLength;
	}

	public void setDataLength(Integer dataLength) {
		this.dataLength = dataLength;
	}

	public Integer getDecimalPlace() {
		return decimalPlace;
	}

	public void setDecimalPlace(Integer decimalPlace) {
		this.decimalPlace = decimalPlace;
	}

	public String getColumnName() {
		return columnName;
	}

	public void setColumnName(String columnName) {
		this.columnName = columnName;
	}

	public boolean getNullFlag() {
		return nullFlag;
	}

	public void setNullFlag(boolean nullFlag) {
		this.nullFlag = nullFlag;
	}

	public boolean getKeyFlag() {
		return keyFlag;
	}

	public void setKeyFlag(boolean keyFlag) {
		this.keyFlag = keyFlag;
	}

	public Long getEntityId() {
		return entityId;
	}

	public void setEntityId(Long entityId) {
		this.entityId = entityId;
	}

	public boolean getSensitiveFlag() {
		return sensitiveFlag;
	}

	public void setSensitiveFlag(boolean sensitiveFlag) {
		this.sensitiveFlag = sensitiveFlag;
	}

	public Integer getSequence() {
		return sequence;
	}

	public void setSequence(Integer sequence) {
		this.sequence = sequence;
	}

	public boolean getRefFlag() {
		return refFlag;
	}

	public void setRefFlag(boolean refFlag) {
		this.refFlag = refFlag;
	}

	public String getRefMapField() {
		return refMapField;
	}

	public void setRefMapField(String refMapField) {
		this.refMapField = refMapField;
	}

	public Long getParentId() {
		return parentId;
	}

	public void setParentId(Long parentId) {
		this.parentId = parentId;
	}

	public String getCode() {
		return code;
	}

	public void setCode(String code) {
		this.code = this.getAttributeName();
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = this.getDisplayName()+"("+this.getAttributeName()+")";
	}

	public boolean getForeignKeyFlag() {
		return foreignKeyFlag;
	}

	public void setForeignKeyFlag(boolean foreignKeyFlag) {
		this.foreignKeyFlag = foreignKeyFlag;
	}

	public String getDataFormat() {
		return dataFormat;
	}

	public void setDataFormat(String dataFormat) {
		this.dataFormat = dataFormat;
	}

	public String getMainAttributeField() {
		return mainAttributeField;
	}

	public void setMainAttributeField(String mainAttributeField) {
		this.mainAttributeField = mainAttributeField;
	}

	public String getSourceType() {
		return sourceType;
	}

	public void setSourceType(String sourceType) {
		this.sourceType = sourceType;
	}

	public String getReferCode() {
		return referCode;
	}

	public void setReferCode(String referCode) {
		this.referCode = referCode;
	}

	public String getCustomDataType() {
		return customDataType;
	}

	public void setCustomDataType(String customDataType) {
		this.customDataType = customDataType;
	}

	public boolean getEditFlag() {
		return editFlag;
	}

	public void setEditFlag(boolean editFlag) {
		this.editFlag = editFlag;
	}
}

==> ejc-metadata-api-3.0.0-20231227.105235-300-sources.jar: com/ejianc/foundation/metadata/vo/MdAttributeVO.java <==
package com.ejianc.foundation.metadata.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

public class MdAttributeVO extends BaseVO {

	private static final long serialVersionUID = 1L;
	public static final String DATA_TYPE_STRING = "string";
	public static final String DATA_TYPE_INTEGER = "integer";
	public static final String DATA_TYPE_LONG = "long";
	public static final String DATA_TYPE_DATETIME = "datetime";
	public static final String DATA_TYPE_DATE = "date";
	public static final String DATA_TYPE_LIST = "list";
	public static final String DATA_TYPE_REFER = "refer";
	public static final String DATA_TYPE_BOOLEAN = "boolean";
	public static final String DATA_TYPE_DECIMAL = "decimal";
	public static final String DATA_TYPE_FLOAT = "float";
	public static final String DATA_TYPE_DOUBLE = "double";

	private String attributeName; // 属性名称

	private String displayName; // 显示名称

	private String dataType; // 数据类型

	private String customDataType; // custom数据类型

	private String description;// 描述

	private Integer dataLength;// 数据长度

	private Integer decimalPlace;// 小数位

	private String columnName; // 列名

	private boolean nullFlag; // 是否为空

	private boolean keyFlag; // 是否主键

	private Long entityId; // 实体ID

	private boolean sensitiveFlag;// 是否是敏感字段

	private Integer sequence;// 排序字段

	private boolean refFlag; // 是否参照字段

	private String refMapField;// 参照映射字段

	private Long parentId; // 其关系表 ， 获取属性参照使用
	private String code;// 流程中心使用
	private String name;// 流程中心使用
	private String mainAttributeField;// 当该实体为子实体时，该字段表示该子实体在主实体中的属性

	private boolean foreignKeyFlag; //是否外键，若是，则该字段为主表主键

	private String dataFormat; //数据格式化，打印使用
	
	private String sourceType; //当该字段为图片时对应的sourceType（附件上传时定义的sourceType），打印图片使用
	
	private String referCode; //参照编码（当字段为参照字段时，填写参照编码）

	/**
	 * 查询时字段排序方式（目前用于打印查询），""-不排序，"desc"-倒序,"asc"-正序
	 */
	private String orderType;

	/**
	 * 查询时字段排序顺序
	 */
	private Integer orderSequence;
	
	private boolean editFlag;// 是否允许审批中可改

	private String mainAttributeName;// 子表名字 业财中台使用
	private String columnPos; // 字段位置:H主表、HR主表关联、B子表、BR子表关联  业财中台使用
	private String attributeFullName; // 属性名称扩展， 有子表时：子表在主表属性名.子表键值

	public String getAttributeFullName() {
		return attributeFullName;
	}

	public void setAttributeFullName(String attributeFullName) {
		this.attributeFullName = attributeFullName;
	}

	public String getMainAttributeName() {
		return mainAttributeName;
	}

	public void setMainAttributeName(String mainAttributeName) {
		this.mainAttributeName = mainAttributeName;
	}

	public String getColumnPos() {
		return columnPos;
	}

	public void setColumnPos(String columnPos) {
		this.columnPos = columnPos;
	}

	public String getOrderType() {
		return orderType;
	}

	public void setOrderType(String orderType) {
		this.orderType = orderType;
	}

	public Integer getOrderSequence() {
		return orderSequence;
	}

	public void setOrderSequence(Integer orderSequence) {
		this.orderSequence = orderSequence;
	}

	public String getAttributeName() {
		return attributeName;
	}

	public void setAttributeName(String attributeName) {
		this.attributeName = attributeName;
	}

	public String getDisplayName() {
		return displayName;
	}

	public void setDisplayName(String displayName) {
		this.displayName = displayName;
	}

	public String getDataType() {
		return dataType;
	}

	public void setDataType(String dataType) {
		this.dataType = dataType;
	}

	public String getDescription() {
		return description;
	}

	public void setDescription(String description) {
		this.description = description;
	}

	public Integer getDataLength() {
		return dataLength;
	}

	public void setDataLength(Integer dataLength) {
		this.dataLength = dataLength;
	}

	public Integer getDecimalPlace() {
		return decimalPlace;
	}

	public void setDecimalPlace(Integer decimalPlace) {
		this.decimalPlace = decimalPlace;
	}

	public String getColumnName() {
		return columnName;
	}

	public void setColumnName(String columnName) {
		this.columnName = columnName;
	}

	public boolean getNullFlag() {
		return nullFlag;
	}

	public void setNullFlag(boolean nullFlag) {
		this.nullFlag = nullFlag;
	}

	public boolean getKeyFlag() {
		return keyFlag;
	}

	public void setKeyFlag(boolean keyFlag) {
		this.keyFlag = keyFlag;
	}

	public Long getEntityId() {
		return entityId;
	}

	public void setEntityId(Long entityId) {
		this.entityId = entityId;
	}

	public boolean getSensitiveFlag() {
		return sensitiveFlag;
	}

	public void setSensitiveFlag(boolean sensitiveFlag) {
		this.sensitiveFlag = sensitiveFlag;
	}

	public Integer getSequence() {
		return sequence;
	}

	public void setSequence(Integer sequence) {
		this.sequence = sequence;
	}

	public boolean getRefFlag() {
		return refFlag;
	}

	public void setRefFlag(boolean refFlag) {
		this.refFlag = refFlag;
	}

	public String getRefMapField() {
		return refMapField;
	}

	public void setRefMapField(String refMapField) {
		this.refMapField = refMapField;
	}

	public Long getParentId() {
		return parentId;
	}

	public void setParentId(Long parentId) {
		this.parentId = parentId;
	}

	public String getCode() {
		return code;
	}

	public void setCode(String code) {
		this.code = this.getAttributeName();
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = this.getDisplayName()+"("+this.getAttributeName()+")";
	}

	public boolean getForeignKeyFlag() {
		return foreignKeyFlag;
	}

	public void setForeignKeyFlag(boolean foreignKeyFlag) {
		this.foreignKeyFlag = foreignKeyFlag;
	}

	public String getDataFormat() {
		return dataFormat;
	}

	public void setDataFormat(String dataFormat) {
		this.dataFormat = dataFormat;
	}

	public String getMainAttributeField() {
		return mainAttributeField;
	}

	public void setMainAttributeField(String mainAttributeField) {
		this.mainAttributeField = mainAttributeField;
	}

	public String getSourceType() {
		return sourceType;
	}

	public void setSourceType(String sourceType) {
		this.sourceType = sourceType;
	}

	public String getReferCode() {
		return referCode;
	}

	public void setReferCode(String referCode) {
		this.referCode = referCode;
	}

	public String getCustomDataType() {
		return customDataType;
	}

	public void setCustomDataType(String customDataType) {
		this.customDataType = customDataType;
	}

	public boolean getEditFlag() {
		return editFlag;
	}

	public void setEditFlag(boolean editFlag) {
		this.editFlag = editFlag;
	}
}
